@@ -257,6 +257,16 @@ class SpeechRecognizer:
         self._prevSpeaking = time.time()
         self._speakingLength = 0
         self._isSpeech = True
+        self._frames.clear()
+        self._wakeWordStreams.clear()
+    
+    def wakeUp(self, emitCallback=True):
+        self.woke = True
+        self._count = 0
+        self._prevSpeaking = time.time()
+
+        if emitCallback:
+            self.callback({"type": "wakeWordDetected"})
     
     def _recognize(self, data, frames, t, st):
         arr = np.frombuffer(data, dtype=np.int16)
@@ -269,12 +279,8 @@ class SpeechRecognizer:
             self._wakeWordStreams.append(data)
 
         if wakeWordIndex >= 0 and not self.woke:
-            self.woke = True
-            self._count = 0
-            self._prevSpeaking = time.time()
-            
-            self.callback({"type": "wakeWordDetected"})
-        
+            self.wakeUp()
+
         if self.woke:
 
             # Collect raw streams used for saving the file (if you want to)
